==> seven-elements-1.0.2%2B1.21.9-sources.jar: io/github/xrickastley/sevenelements/renderer/SevenElementsRenderPipelines.java <==
package io.github.xrickastley.sevenelements.renderer;

import com.mojang.blaze3d.pipeline.BlendFunction;
import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.mojang.blaze3d.platform.DepthTestFunction;
import com.mojang.blaze3d.platform.DestFactor;
import com.mojang.blaze3d.platform.SourceFactor;
import com.mojang.blaze3d.vertex.VertexFormat;
import com.mojang.blaze3d.vertex.VertexFormat.class_5596;
import io.github.xrickastley.sevenelements.SevenElements;
import net.minecraft.class_10799;
import net.minecraft.class_290;

public class SevenElementsRenderPipelines {
	private static final RenderPipeline.Snippet TRIANGLES_SNIPPET = RenderPipeline.builder(class_10799.field_56860)
		.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27379)
		.buildSnippet();

	public static final RenderPipeline TRIANGLES = class_10799.method_67887(
		RenderPipeline.builder(SevenElementsRenderPipelines.TRIANGLES_SNIPPET)
			.withLocation(SevenElements.identifier("pipeline/triangles"))
			.build()
	);

	public static final RenderPipeline QUADS = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56860)
			.withLocation(SevenElements.identifier("pipeline/quads"))
			.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27382)
			.build()
	);

	public static final RenderPipeline LINES = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56859)
			.withLocation(SevenElements.identifier("pipeline/lines"))
			.withVertexFormat(class_290.field_29337, VertexFormat.class_5596.field_27377)
			.withoutBlend()
			.withCull(false)
			.build()
	);

	public static final RenderPipeline CIRCLE = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56864)
			.withLocation(SevenElements.identifier("pipeline/circle"))
			.withFragmentShader(SevenElements.identifier("circle"))
			.build()
	);

	public static final RenderPipeline ELEMENTS = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56864)
			.withLocation(SevenElements.identifier("pipeline/elements"))
			.withVertexFormat(class_290.field_1575, class_5596.field_27382)
			.withBlend(BlendFunction.TRANSLUCENT)
			.withCull(false)
			.build()
	);

	public static final RenderPipeline WORLD_TEXT = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56854)
			.withLocation(SevenElements.identifier("pipeline/world_text"))
			.withVertexFormat(class_290.field_1585, class_5596.field_27382)
			.withCull(false)
			.withDepthWrite(false)
			.build()
	);

	public static final RenderPipeline CHARGE_LINE = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56859)
			.withLocation(SevenElements.identifier("pipeline/charge_line"))
			.withBlend(BlendFunction.TRANSLUCENT)
			.withCull(false)
			.build()
	);

	public static final RenderPipeline SPHERE = class_10799.method_67887(
		RenderPipeline.builder(SevenElementsRenderPipelines.TRIANGLES_SNIPPET)
			.withLocation(SevenElements.identifier("pipeline/sphere"))
			.withCull(false)
			.withBlend(new BlendFunction(SourceFactor.SRC_ALPHA, DestFactor.ONE_MINUS_SRC_ALPHA, SourceFactor.ONE, DestFactor.ZERO))
			.withDepthTestFunction(DepthTestFunction.LEQUAL_DEPTH_TEST)
			.withDepthWrite(false)
			.build()
	);
}

==> seven-elements-1.0.3%2B1.21.5-sources.jar: io/github/xrickastley/sevenelements/renderer/SevenElementsRenderPipelines.java <==
package io.github.xrickastley.sevenelements.renderer;

import com.mojang.blaze3d.pipeline.BlendFunction;
import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.mojang.blaze3d.platform.DepthTestFunction;
import com.mojang.blaze3d.vertex.VertexFormat;
import com.mojang.blaze3d.vertex.VertexFormat.class_5596;
import io.github.xrickastley.sevenelements.SevenElements;
import net.minecraft.class_10799;
import net.minecraft.class_290;

public class SevenElementsRenderPipelines {
	private static final RenderPipeline.Snippet TRIANGLES_SNIPPET = RenderPipeline.builder(class_10799.field_56860)
		.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27379)
		.buildSnippet();

	public static final RenderPipeline TRIANGLES = class_10799.method_67887(
		RenderPipeline.builder(SevenElementsRenderPipelines.TRIANGLES_SNIPPET)
			.withLocation(SevenElements.identifier("pipeline/triangles"))
			.build()
	);

	public static final RenderPipeline TRIANGLE_FAN = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56860)
			.withLocation(SevenElements.identifier("pipeline/triangle_fan"))
			.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27381)
			.build()
	);

	public static final RenderPipeline TRIANGLE_STRIP = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56860)
			.withLocation(SevenElements.identifier("pipeline/triangle_strip"))
			.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27380)
			.build()
	);

	public static final RenderPipeline QUADS = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56860)
			.withLocation(SevenElements.identifier("pipeline/quads"))
			.withVertexFormat(class_290.field_1576, VertexFormat.class_5596.field_27382)
			.build()
	);

	public static final RenderPipeline LINES = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56859)
			.withLocation(SevenElements.identifier("pipeline/lines"))
			.withVertexFormat(class_290.field_29337, VertexFormat.class_5596.field_27377)
			.withoutBlend()
			.withCull(false)
			.build()
	);

	public static final RenderPipeline ELEMENTS = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56864)
			.withLocation(SevenElements.identifier("pipeline/elements"))
			.withVertexFormat(class_290.field_1575, class_5596.field_27382)
			.withBlend(BlendFunction.TRANSLUCENT)
			.withCull(false)
			.build()
	);

	public static final RenderPipeline WORLD_TEXT = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56854)
			.withLocation(SevenElements.identifier("pipeline/world_text"))
			.withVertexFormat(class_290.field_1585, class_5596.field_27382)
			.withCull(false)
			.withDepthWrite(false)
			.build()
	);

	public static final RenderPipeline CHARGE_LINE = class_10799.method_67887(
		RenderPipeline.builder(class_10799.field_56859)
			.withLocation(SevenElements.identifier("pipeline/charge_line"))
			.withBlend(BlendFunction.TRANSLUCENT)
			.withCull(false)
			.build()
	);

	public static final RenderPipeline SPHERE = class_10799.method_67887(
		RenderPipeline.builder(SevenElementsRenderPipelines.TRIANGLES_SNIPPET)
			.withLocation(SevenElements.identifier("pipeline/sphere"))
			.withCull(false)
			.withBlend(BlendFunction.PANORAMA)
			.withDepthTestFunction(DepthTestFunction.LEQUAL_DEPTH_TEST)
			.withDepthWrite(false)
			.build()
	);
}
